@@ -6,60 +6,77 @@ import (
 	"strings"
 	"text/template"
 
-	"github.com/aquasecurity/tfsec/pkg/provider"
-	"github.com/aquasecurity/tfsec/pkg/rule"
+	"github.com/aquasecurity/defsec/provider"
 )
 
 const (
 	baseWebPageTemplate = `---
-title: {{$.ShortCode}}
+title: {{$.Summary}}
 ---
 
+# {{$.Summary}}
+
+### Default Severity: <span class="severity {{$.Severity | ToLower }}">{{$.Severity }}</span>
+
 ### Explanation
 
-{{$.Documentation.Explanation}}
+{{$.Explanation}}
 
 ### Possible Impact
-{{$.Documentation.Impact}}
+{{$.Impact}}
 
 ### Suggested Resolution
-{{$.Documentation.Resolution}}
+{{$.Resolution}}
 
-{{if $.Documentation.BadExample }}
+{{if $.BadExample }}
 ### Insecure Example
 
 The following example will fail the {{$.ID}} check.
-
 ` + "```terraform" + `
-{{ (index $.Documentation.BadExample 0) }}
+{{ $.BadExample }}
 ` + "```" + `
 
 {{end}}
-{{if $.Documentation.GoodExample }}
+{{if $.GoodExample }}
 ### Secure Example
 
 The following example will pass the {{$.ID}} check.
-
 ` + "```terraform" + `
-{{ (index $.Documentation.GoodExample 0) }}
+{{ $.GoodExample }}
 ` + "```" + `
-
 {{end}}
 
-{{if $.Documentation.Links}}
-### Related Links
+{{if $.Links}}
+### Links
 
-{{range $link := $.Documentation.Links}}
+{{range $link := $.Links}}
 - [{{.}}]({{.}}){:target="_blank" rel="nofollow noreferrer noopener"}
 {{end}}
 {{end}}
+
 `
 )
 
+type templateObject struct {
+	ID          string
+	ShortCode   string
+	LegacyID    string
+	Severity    string
+	Summary     string
+	Service     string
+	Provider    string
+	Explanation string
+	Impact      string
+	Resolution  string
+	BadExample  string
+	GoodExample string
+	Links       []string
+}
+
 func generateWebPages(fileContents []*FileContent) error {
 	for _, contents := range fileContents {
 		for _, check := range contents.Checks {
-			webProviderPath := fmt.Sprintf("docs/checks/%s/%s", strings.ToLower(string(check.Provider)), strings.ToLower(check.Service))
+			webProviderPath := fmt.Sprintf("%s/%s/%s", webPath, strings.ToLower(check.Provider), strings.ToLower(check.Service))
 			if err := generateWebPage(webProviderPath, check); err != nil {
 				return err
 			}
@@ -70,6 +87,7 @@ func generateWebPages(fileContents []*FileContent) error {
 
 var funcMap = template.FuncMap{
 	"ToUpper":            strings.ToUpper,
+	"ToLower":            strings.ToLower,
 	"FormatProviderName": formatProviderName,
 	"Join":               join,
 }
@@ -88,13 +106,13 @@ func formatProviderName(providerName string) string {
 	return provider.Provider(providerName).DisplayName()
 }
 
-func generateWebPage(webProviderPath string, r rule.Rule) error {
+func generateWebPage(webProviderPath string, r templateObject) error {
 
 	if err := os.MkdirAll(webProviderPath, os.ModePerm); err != nil {
 		return err
 	}
 	filePath := fmt.Sprintf("%s/%s.md", webProviderPath, r.ShortCode)
-	fmt.Printf("Generating page for %s at %s\n", r.ID(), filePath)
+	fmt.Printf("Generating page for %s at %s\n", r.ID, filePath)
 	webTmpl := template.Must(template.New("web").Funcs(funcMap).Parse(baseWebPageTemplate))
 
 	return writeTemplate(r, filePath, webTmpl)
